@@ -1,7 +1,3 @@
-context("test-to-vega.R")
-
-library("magrittr")
-
 has_node <- unname(nchar(Sys.which("node")) > 0L)
 
 test_that("vw_to_vega works", {
@@ -10,12 +6,12 @@ test_that("vw_to_vega works", {
   skip_on_cran()
   skip_if_not(has_node)
 
-  spec_mtcars_vega <-
-    "../spec/spec_mtcars.vg.5.json" %>%
-    readLines() %>%
-    as_vegaspec()
+  spec_mtcars_vega <- vw_to_vega(spec_mtcars)
 
-  expect_identical(vw_to_vega(spec_mtcars), spec_mtcars_vega)
+  # use snapshot test
+  expect_snapshot(vw_as_json(vw_to_vega(spec_mtcars_vega)))
+
+  # expect no-op
   expect_identical(vw_to_vega(spec_mtcars_vega), spec_mtcars_vega)
 
 })
