@@ -1,7 +1,3 @@
-context("test-vegaspec.R")
-
-library("magrittr")
-
 has_node <- unname(nchar(Sys.which("node")) > 0L)
 
 test_that("as_vegaspec translates", {
@@ -17,17 +13,17 @@ test_that("as_vegaspec translates", {
 
 test_that("class is correct", {
 
-  expect_is(as_vegaspec(unclass(spec_mtcars)), "list")
-  expect_is(as_vegaspec(unclass(spec_mtcars)), "vegaspec")
-  expect_is(as_vegaspec(unclass(spec_mtcars)), "vegaspec_vega_lite")
+  expect_type(as_vegaspec(unclass(spec_mtcars)), "list")
+  expect_s3_class(as_vegaspec(unclass(spec_mtcars)), "vegaspec")
+  expect_s3_class(as_vegaspec(unclass(spec_mtcars)), "vegaspec_vega_lite")
 
   # Need to have node installed
   skip_on_cran()
   skip_if_not(has_node)
 
-  expect_is(vw_to_vega(spec_mtcars), "list")
-  expect_is(vw_to_vega(spec_mtcars), "vegaspec")
-  expect_is(vw_to_vega(spec_mtcars), "vegaspec_vega")
+  expect_type(vw_to_vega(spec_mtcars), "list")
+  expect_s3_class(vw_to_vega(spec_mtcars), "vegaspec")
+  expect_s3_class(vw_to_vega(spec_mtcars), "vegaspec_vega")
 
 })
 
@@ -61,6 +57,32 @@ test_that("vegaspec without $schema warns and adds element", {
 
 })
 
+test_that("as_vegaspec reads UTF-8 correctly", {
+
+  filename <- "test_encoding_utf8.vl4.json"
+  description <- "ceci une version allégée d'une spécification vega-lite"
+
+  # cleans up file
+  withr::local_file(filename)
+
+  fileConn <- file(filename, encoding = "UTF-8")
+  writeLines(
+    glue_js(
+      "{",
+      "  \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.json\",",
+      "  \"description\": \"${description}\"",
+      "}"
+    ),
+    fileConn
+  )
+  close(fileConn)
+
+  myspec <- vegawidget::as_vegaspec(filename)
+
+  expect_identical(myspec$description, description)
+
+})
+
 
 
 
